<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Edufication
 * @since Edufication 1.0.0
 */

$options = edufication_get_theme_options();


if ( ! function_exists( 'edufication_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Edufication 1.0.0
	 */
	function edufication_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'edufication_doctype', 'edufication_doctype', 10 );


if ( ! function_exists( 'edufication_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'edufication_before_wp_head', 'edufication_head', 10 );

if ( ! function_exists( 'edufication_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'edufication' ); ?></a>

		<?php
	}
endif;
add_action( 'edufication_page_start_action', 'edufication_page_start', 10 );

if ( ! function_exists( 'edufication_top_menu' ) ) :
	/**
	 * Top menu html codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_top_menu() {
		$options = edufication_get_theme_options();
		if ( ! $options['topbar_section_enable'] )
			return;
		?>
		<div id="top-header" class="relative col-2">
            <div class="wrapper">
                <?php  
                /**
				 * edufication_topbar_news_action hook
				 *
				 * @hooked edufication_add_topbar_section -  10
				 *
				 */
				do_action( 'edufication_topbar_news_action' );
                ?>
                <button class="topheader-dropdown">
                    <?php echo edufication_get_svg( array( 'icon' => 'down' ) ); ?>
                </button><!-- .topheader-dropdown -->
                <div class="contact-info col-<?php echo ( has_nav_menu( 'social' ) ) ? 2 : 1; ?>">
                    <div class="contact-details">
                        <ul>
                            <?php if ( ! empty( $options['topbar_phone'] ) ) : ?>
		                    	<li class="topbar-phone"><a href="tel:<?php echo esc_attr( $options['topbar_phone'] ) ?>"><?php echo edufication_get_svg( array( 'icon' => 'phone' ) ) . esc_html( $options['topbar_phone'] ); ?></a></li>
	                    	<?php endif; ?>

                            <?php if ( ! empty( $options['topbar_email'] ) ) : ?>
			                    <li class="topbar-email" ><a href="mailto:<?php echo esc_attr( $options['topbar_email'] ); ?>"><?php echo edufication_get_svg( array( 'icon' => 'envelope' ) ) . esc_html( $options['topbar_email'] ); ?></a></li>
			                <?php endif; ?>
                        </ul>
                    </div><!-- .contact-details -->
                    <?php if ( has_nav_menu( 'social' ) && wp_get_theme()->Name !== 'Edufication' ) : ?>
			            <div class="social-icons">
			            	<?php  
			            		wp_nav_menu( array(
			            			'theme_location' => 'social',
			            			'container' => false,
			            			'menu_class' => 'menu',
			            			'echo' => true,
			            			'fallback_cb' => 'edufication_menu_fallback_cb',
			            			'depth' => 1,
			            			'link_before' => '<span class="screen-reader-text">',
									'link_after' => '</span>',
			            		) );
			            	?>
			            </div><!-- .social-icons -->
			        <?php endif; ?>
                </div><!-- .contact-info -->                
            </div><!-- .wrapper -->
        </div><!-- #top-header -->
	<?php
	}
endif;
add_action( 'edufication_page_start_action', 'edufication_top_menu', 30 );

if ( ! function_exists( 'edufication_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'edufication_page_end_action', 'edufication_page_end', 10 );

if ( ! function_exists( 'edufication_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_header_start() { ?>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
		<?php
	}
endif;
add_action( 'edufication_header_action', 'edufication_header_start', 10 );

if ( ! function_exists( 'edufication_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_site_branding() {
		$options  = edufication_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-identity">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( edufication_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
			<?php endif; ?>
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'edufication_header_action', 'edufication_site_branding', 20 );

if ( ! function_exists( 'edufication_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_site_navigation() {
		$options = edufication_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<span class="menu-label"><?php esc_html_e( 'Menu', 'edufication' ); ?></span>
				<?php
				echo edufication_get_svg( array( 'icon' => 'menu' ) );
				echo edufication_get_svg( array( 'icon' => 'close' ) );
				?>					
			</button>

			<?php  
				$search = '';
				$search = '<li class="search-menu"><a href="#">';
				$search .= edufication_get_svg( array( 'icon' => 'search' ) );
				$search .= edufication_get_svg( array( 'icon' => 'close' ) );
				$search .= '</a><div id="search">';
				$search .= get_search_form( $echo = false );
                $search .= '</div><!-- #search --></li>';        

        		wp_nav_menu( array(
        			'theme_location' => 'primary',
        			'container' => false,
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'edufication_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
        		) );
        	?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'edufication_header_action', 'edufication_site_navigation', 30 );


if ( ! function_exists( 'edufication_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_header_end() {
		?>
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'edufication_header_action', 'edufication_header_end', 50 );

if ( ! function_exists( 'edufication_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'edufication_content_start_action', 'edufication_content_start', 10 );

if ( ! function_exists( 'edufication_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Edufication 1.0.0
	 */
	function edufication_add_breadcrumb() {
		$options = edufication_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( edufication_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >
			<div class="wrapper">';
				/**
				 * edufication_simple_breadcrumb hook
				 *
				 * @hooked edufication_simple_breadcrumb -  10
				 *
				 */
				do_action( 'edufication_simple_breadcrumb' );
		echo '</div>
			</div><!-- #breadcrumb-list -->';
		return;
	}
endif;

if ( ! function_exists( 'edufication_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_header_image() {
		$options = edufication_get_theme_options();
		if ( edufication_is_frontpage() )
			return;
		$header_image = get_header_image(); 
		$header_image = ! empty( $header_image ) ? get_header_image() : get_template_directory_uri() . '/assets/uploads/header-image.jpg';
		if ( is_singular() ) :
			$header_image = ( has_post_thumbnail() ) ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
		endif;
		?>

		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <h2 class="page-title"><?php edufication_custom_header_banner_title(); ?></h2>
                </header>

                <?php 
                edufication_add_breadcrumb(); 
                ?>

            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->

		<?php
	}
endif;
add_action( 'edufication_header_image_action', 'edufication_header_image', 10 );

if ( ! function_exists( 'edufication_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'edufication_content_end_action', 'edufication_content_end', 10 );

if ( ! function_exists( 'edufication_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'edufication_footer', 'edufication_footer_start', 10 );

if ( ! function_exists( 'edufication_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_footer_site_info() {
		$options = edufication_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_html( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] ); 

		$copyright_text = $options['copyright_text']; 

		?>

		<div class="site-info col-2">
                <div class="wrapper">
                    <span class="copyright"><?php echo edufication_santize_allow_tag( $copyright_text ); 
                    if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
					}?></span>
                    <?php if ( has_nav_menu( 'social' ) && $options['footer_social_visible'] ) : ?>
	                    <div class="social-icons">
	                        <?php  
			            	
			            		wp_nav_menu( array(
			            			'theme_location' => 'social',
			            			'container' => false,
			            			'menu_class' => 'menu',
			            			'echo' => true,
			            			'fallback_cb' => false,
			            			'depth' => 1,
			            			'link_before' => '<span class="screen-reader-text">',
									'link_after' => '</span>',
			            		) );
			            	?>
	                    </div><!-- .social-icons -->
	                <?php endif; ?>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->


		<?php
	}
endif;
add_action( 'edufication_footer', 'edufication_footer_site_info', 40 );

if ( ! function_exists( 'edufication_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Edufication 1.0.0
	 *
	 */
	function edufication_footer_scroll_to_top() {
		$options  = edufication_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo edufication_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'edufication_footer', 'edufication_footer_scroll_to_top', 40 );

